import QtQuick 2.6
import org.kde.kirigami 2.4 as Kirigami
import QtQuick.Controls 2.0 as Controls
import QtQuick.Layouts 1.12 as Layouts
import org.eyecreate.qiflora 1.0

Kirigami.ApplicationWindow {
    id: root

    title: "QiFlora"
    

    pageStack.initialPage: mainPageComponent
    
    QiFlora {
        id: qiflora
    }

    Component {
        id: mainPageComponent

        Kirigami.ScrollablePage {
            mainAction: Kirigami.Action {
                    iconName: "view-refresh"
                    text: i18n("Query Device")
                    onTriggered: {
                        deviceSelect.open();
                    }
            }
            title: "Monitor"
            
            Component.onCompleted: {
                monitorTypes.append({"chartType": "temperature", "title": i18n("Temperature"), "icon": "filename-bpm-amarok"});
                monitorTypes.append({"chartType": "moisture", "title": i18n("Moisture"), "icon": "colors-chromablue"});
                monitorTypes.append({"chartType": "conductivity", "title": i18n("Conductivity"), "icon": "quickopen"});
                monitorTypes.append({"chartType": "brightness", "title": i18n("Brightness"), "icon": "contrast"});
            }

            Kirigami.CardsListView {
                id: monitorView
                model: ListModel {
                    id: monitorTypes
                }
                
                delegate: Kirigami.Card {
                    id: card
                    banner {
                        title: model.title
                        titleIcon: model.icon
                        titleLevel: 2
                    }
                    header: Row {
                        layoutDirection: Qt.RightToLeft
                        topPadding: 10.0
                        rightPadding: 10.0
                        Layouts.ColumnLayout {
                            Kirigami.Heading {
                                Layouts.Layout.alignment: Qt.AlignCenter
                                level: 4
                                text: i18n("Last Measured")
                            }
                            Kirigami.Heading {
                                Layouts.Layout.alignment: Qt.AlignCenter
                                level: 3
                                text: {
                                    if(model.chartType == "temperature") qiflora.temperature + "°C"
                                    else if(model.chartType == "moisture") qiflora.moisture + "%"
                                    else if(model.chartType == "conductivity") qiflora.conduction + " µS/cm"
                                    else if(model.chartType == "brightness") qiflora.brightness + " lux"
                                }
                            }
                        }
                    }
                    contentItem: Controls.Label {
                            wrapMode: Text.WordWrap
                            text: i18n("") //TODO: replace with graph?
                        }
                }
            }
            
            Kirigami.OverlaySheet {
                id: deviceSelect
                showCloseButton: false
                contentItem: ListView {
                        header: Column {
                            Rectangle {
                                height: 10
                                color: "transparent"
                                width: parent.width
                            }
                            Kirigami.Heading {
                                text: i18n("Select Device to Query")
                            }
                            Rectangle {
                                height: 10
                                color: "transparent"
                                width: parent.width
                            }
                        }
                        id: deviceList
                        model: qiflora.devices
                        delegate: Kirigami.AbstractListItem {
                            Layouts.ColumnLayout {
                                Kirigami.Heading {
                                    text:model.modelData.name
                                    level: 2
                                }
                                Kirigami.Heading {
                                    text:model.modelData.address
                                    level: 5
                                }
                            }
                            onClicked: {
                                qiflora.updateDataFromDevice(model.modelData.address);
                                deviceSelect.close();
                            }
                        }
                }
                onSheetOpenChanged: {
                    if(!sheetOpen) {
                        qiflora.stopSearch();
                    } else {
                        qiflora.startSearch();
                    }
                }
            }
        }
    }
}
